@@ -378,7 +378,7 @@ def start(format: bool = False):
         else:
             docstring += f"Telegram API method.\n\n"
 
-        docstring += f"    Details:\n        - Layer: ``{layer}``\n        - ID: ``{c.id}``\n\n"
+        docstring += f"    Details:\n        - Layer: ``{layer}``\n        - ID: ``{c.id[2:].upper()}``\n\n"
 
         if docstring_args:
             docstring += "    Parameters:\n        " + "\n        ".join(docstring_args)
@@ -444,7 +444,7 @@ def start(format: bool = False):
                     sub_type = arg_type.split("<")[1][:-1]
 
                     write_types += "\n        "
-                    write_types += f"if self.{arg_name}:\n            "
+                    write_types += f"if self.{arg_name} is not None:\n            "
                     write_types += "b.write(Vector(self.{}{}))\n        ".format(
                         arg_name, f", {sub_type.title()}" if sub_type in CORE_TYPES else ""
                     )
